eval_expr_from_string

Function eval_expr_from_string 

pub fn eval_expr_from_string(s: &str) -> Result<f64, MyError>
Evaluate an expression from a string input and return the result.

Arguments

  • s - A string representing the expression to be evaluated.

Returns

A Result containing the numerical result of the evaluated expression, or an error if parsing fails.